/*
 * Copyright (c) 1998 World Wide Web Consortium, (Massachusetts Institute of
 * Technology, Institut National de Recherche en Informatique et en
 * Automatique, Keio University).
 * All Rights Reserved. http://www.w3.org/Consortium/Legal/
 */

package org.w3c.dom.css;

import org.w3c.dom.*;

/**
 *  The <code>CSSStyleSheet</code> interface is a concrete interface used to 
 * represent a CSS style sheet i.e. a style sheet whose content type is 
 * "text/css". 
 */
public interface CSSStyleSheet extends StyleSheet {
  /**
   *  The collection of all CSS rules contained within the style sheet. This 
   * includes both rule sets and  at-rules. 
   */
  public CSSRuleCollection  getCssRules();
  /**
   *  Used to insert a new rule into the style sheet. The new rule now becomes 
   * part of the cascade. 
   * @param rule  The parsable text representing the rule. For rule sets this 
   *   contains both the selector and the style declaration. For at-rules, 
   *   this specifies both the at-identifier and the rule content. 
   * @param index   The index within the style sheet's rule collection of the 
   *   rule  before which to insert the specified rule. If the  specified 
   *   index is equal to the length of the style sheet's rule collection, the 
   *   rule will be added to the end of the style sheet. 
   * @return  The index within the style sheet's rule collection of the newly 
   *   inserted rule. 
   * @exception DOMException
   *   HIERARCHY_REQUEST_ERR: Raised if the rule cannot be inserted at the 
   *   specified index e.g. if an <code>@import</code> rule is inserted after 
   *   a standard rule set or other at-rule.
   *   <br>INDEX_SIZE_ERR: Raised if the specified index is not a valid 
   *   insertion point.
   *   <br>SYNTAX_ERR: Raised if the specified rule has a syntax error  and 
   *   is unparsable.
   */
  public int                insertRule(String rule, 
                                       int index)
                                       throws DOMException;
  /**
   *  Used to delete a rule from the style sheet. 
   * @param index  The index within the style sheet's rule collection of the 
   *   rule to remove. 
   * @exception DOMException
   *   INDEX_SIZE_ERR: Raised if the specified index does not correspond to a 
   *   rule in the style sheet's rule collection.
   */
  public void               deleteRule(int index)
                                       throws DOMException;
}

